# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dv_pyclient/grpc/dataSources.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from dv_pyclient.grpc import scalapb_pb2 as dv__pyclient_dot_grpc_dot_scalapb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dv_pyclient/grpc/dataSources.proto',
  package='com.datavorelabs.common.protos',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\"dv_pyclient/grpc/dataSources.proto\x12\x1e\x63om.datavorelabs.common.protos\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1e\x64v_pyclient/grpc/scalapb.proto\"X\n\x0eOptionalString\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue:\x19\xe2?\x16\"\x14scala.Option[String]\"X\n\x0eOptionalNumber\x12+\n\x05value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue:\x19\xe2?\x16\"\x14scala.Option[Double]\"S\n\x0cOptionalTime\x12*\n\x05value\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value:\x17\xe2?\x14\"\x12scala.Option[Long]\"\xba\x02\n\nDataRecord\x12\x64\n\x07strings\x18\x01 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalStringB#\xe2? \x1a\x1e\x63ollection.mutable.ArrayBuffer\x12\x64\n\x07numbers\x18\x02 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalNumberB#\xe2? \x1a\x1e\x63ollection.mutable.ArrayBuffer\x12`\n\x05times\x18\x03 \x03(\x0b\x32,.com.datavorelabs.common.protos.OptionalTimeB#\xe2? \x1a\x1e\x63ollection.mutable.ArrayBuffer\"O\n\x10\x44\x61taRecordsReply\x12;\n\x07records\x18\x01 \x03(\x0b\x32*.com.datavorelabs.common.protos.DataRecord\"\x18\n\x16ListDataSourcesRequest\",\n\x10\x44\x61taSourceResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"]\n\x14ListDataSourcesReply\x12\x45\n\x0b\x64\x61taSources\x18\x01 \x03(\x0b\x32\x30.com.datavorelabs.common.protos.DataSourceResult\"A\n\x18\x44\x61taSourceUniquesRequest\x12\x14\n\x0c\x64\x61taSourceId\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\"-\n\x15\x44\x61taSourceMetaRequest\x12\x14\n\x0c\x64\x61taSourceId\x18\x01 \x01(\t\"\xad\x01\n\x12StringColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12\x43\n\x08modifier\x18\x03 \x01(\x0e\x32\x31.com.datavorelabs.common.protos.PredicateModifier\x12.\n\x08ontology\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"8\n\x12NumberColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\"J\n\x10TimeColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12\x12\n\ndateFormat\x18\x03 \x01(\t\"\xe0\x01\n\x18StaticStringColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12+\n\x05value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x43\n\x08modifier\x18\x04 \x01(\x0e\x32\x31.com.datavorelabs.common.protos.PredicateModifier\x12.\n\x08ontology\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"k\n\x18StaticNumberColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12+\n\x05value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\"h\n\x16StaticTimeColumnConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplayLabel\x18\x02 \x01(\t\x12*\n\x05value\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xa6\x04\n\x0c\x43olumnConfig\x12P\n\x12stringColumnConfig\x18\x01 \x01(\x0b\x32\x32.com.datavorelabs.common.protos.StringColumnConfigH\x00\x12P\n\x12numberColumnConfig\x18\x02 \x01(\x0b\x32\x32.com.datavorelabs.common.protos.NumberColumnConfigH\x00\x12L\n\x10timeColumnConfig\x18\x03 \x01(\x0b\x32\x30.com.datavorelabs.common.protos.TimeColumnConfigH\x00\x12\\\n\x18staticStringColumnConfig\x18\x04 \x01(\x0b\x32\x38.com.datavorelabs.common.protos.StaticStringColumnConfigH\x00\x12\\\n\x18staticNumberColumnConfig\x18\x05 \x01(\x0b\x32\x38.com.datavorelabs.common.protos.StaticNumberColumnConfigH\x00\x12X\n\x16staticTimeColumnConfig\x18\x06 \x01(\x0b\x32\x36.com.datavorelabs.common.protos.StaticTimeColumnConfigH\x00\x42\x0e\n\x0c\x63olumnConfig\":\n\x0fTimeTupleConfig\x12\x12\n\ntimeColumn\x18\x01 \x01(\t\x12\x13\n\x0bvalueColumn\x18\x02 \x01(\t\"\xe2\x01\n\x0f\x44\x61taLoadMapping\x12\x12\n\nkeyColumns\x18\x01 \x03(\t\x12\x16\n\x0evalueModifiers\x18\x02 \x03(\t\x12\x13\n\x0btimeColumns\x18\x03 \x03(\t\x12/\n\tfrequency\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x18\n\x10valueLabelColumn\x18\x05 \x03(\t\x12\x43\n\ntimeTuples\x18\x06 \x03(\x0b\x32/.com.datavorelabs.common.protos.TimeTupleConfig\"2\n\x0c\x43olumnSample\x12\x12\n\ncolumnName\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"K\n\tRowSample\x12>\n\x06values\x18\x02 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalString\"\xd6\x02\n\x13\x44\x61taSourceMetaReply\x12\x14\n\x0c\x64\x61taSourceId\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61taSourceName\x18\x02 \x01(\t\x12\x43\n\rcolumnConfigs\x18\x03 \x03(\x0b\x32,.com.datavorelabs.common.protos.ColumnConfig\x12H\n\x0f\x64\x61taLoadMapping\x18\x04 \x01(\x0b\x32/.com.datavorelabs.common.protos.DataLoadMapping\x12=\n\nsampleData\x18\x05 \x03(\x0b\x32).com.datavorelabs.common.protos.RowSample\x12\x43\n\rcolumnSamples\x18\x06 \x03(\x0b\x32,.com.datavorelabs.common.protos.ColumnSample\"\xe4\x01\n\x0eLineDefinition\x12\x17\n\x0fkeyPredicateIds\x18\x01 \x03(\t\x12?\n\x07keyPath\x18\x02 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalString\x12\x17\n\x0ftimePredicateId\x18\x03 \x01(\t\x12\x18\n\x10valuePredicateId\x18\x04 \x01(\t\x12/\n\tfrequency\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x14\n\x0c\x64\x61taSourceId\x18\x06 \x01(\t\"\xa3\x02\n\x0bQueryColumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32*.com.datavorelabs.common.protos.ColumnType\x12\x44\n\x0cstringFilter\x18\x03 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalString\x12\x44\n\x0cnumberFilter\x18\x04 \x03(\x0b\x32..com.datavorelabs.common.protos.OptionalNumber\x12@\n\ntimeFilter\x18\x05 \x03(\x0b\x32,.com.datavorelabs.common.protos.OptionalTime\"I\n\tLineQuery\x12<\n\x07\x63olumns\x18\x01 \x03(\x0b\x32+.com.datavorelabs.common.protos.QueryColumn\"X\n\x16\x44\x61taSourceQueryRequest\x12>\n\x0blineQueries\x18\x01 \x03(\x0b\x32).com.datavorelabs.common.protos.LineQuery*B\n\x11PredicateModifier\x12\x08\n\x04None\x10\x00\x12\x10\n\x0cTimeModifier\x10\x01\x12\x11\n\rValueModifier\x10\x02*.\n\nColumnType\x12\n\n\x06String\x10\x00\x12\n\n\x06Number\x10\x01\x12\x08\n\x04Time\x10\x02\x32\xa4\x04\n\x10RemoteDataSource\x12\x81\x01\n\x0fListDataSources\x12\x36.com.datavorelabs.common.protos.ListDataSourcesRequest\x1a\x34.com.datavorelabs.common.protos.ListDataSourcesReply\"\x00\x12\x83\x01\n\x11\x64\x61taSourceUniques\x12\x38.com.datavorelabs.common.protos.DataSourceUniquesRequest\x1a\x30.com.datavorelabs.common.protos.DataRecordsReply\"\x00\x30\x01\x12\x84\x01\n\x14sampleDataSourceMeta\x12\x35.com.datavorelabs.common.protos.DataSourceMetaRequest\x1a\x33.com.datavorelabs.common.protos.DataSourceMetaReply\"\x00\x12\x7f\n\x0f\x64\x61taSourceQuery\x12\x36.com.datavorelabs.common.protos.DataSourceQueryRequest\x1a\x30.com.datavorelabs.common.protos.DataRecordsReply\"\x00\x30\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,dv__pyclient_dot_grpc_dot_scalapb__pb2.DESCRIPTOR,])

_PREDICATEMODIFIER = _descriptor.EnumDescriptor(
  name='PredicateModifier',
  full_name='com.datavorelabs.common.protos.PredicateModifier',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TimeModifier', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueModifier', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3836,
  serialized_end=3902,
)
_sym_db.RegisterEnumDescriptor(_PREDICATEMODIFIER)

PredicateModifier = enum_type_wrapper.EnumTypeWrapper(_PREDICATEMODIFIER)
_COLUMNTYPE = _descriptor.EnumDescriptor(
  name='ColumnType',
  full_name='com.datavorelabs.common.protos.ColumnType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='String', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Number', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Time', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3904,
  serialized_end=3950,
)
_sym_db.RegisterEnumDescriptor(_COLUMNTYPE)

ColumnType = enum_type_wrapper.EnumTypeWrapper(_COLUMNTYPE)
globals()['None'] = 0
TimeModifier = 1
ValueModifier = 2
String = 0
Number = 1
Time = 2



_OPTIONALSTRING = _descriptor.Descriptor(
  name='OptionalString',
  full_name='com.datavorelabs.common.protos.OptionalString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.OptionalString.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\026\"\024scala.Option[String]',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=222,
)


_OPTIONALNUMBER = _descriptor.Descriptor(
  name='OptionalNumber',
  full_name='com.datavorelabs.common.protos.OptionalNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.OptionalNumber.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\026\"\024scala.Option[Double]',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=312,
)


_OPTIONALTIME = _descriptor.Descriptor(
  name='OptionalTime',
  full_name='com.datavorelabs.common.protos.OptionalTime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.OptionalTime.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\342?\024\"\022scala.Option[Long]',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=397,
)


_DATARECORD = _descriptor.Descriptor(
  name='DataRecord',
  full_name='com.datavorelabs.common.protos.DataRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='strings', full_name='com.datavorelabs.common.protos.DataRecord.strings', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342? \032\036collection.mutable.ArrayBuffer', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numbers', full_name='com.datavorelabs.common.protos.DataRecord.numbers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342? \032\036collection.mutable.ArrayBuffer', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='times', full_name='com.datavorelabs.common.protos.DataRecord.times', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342? \032\036collection.mutable.ArrayBuffer', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=714,
)


_DATARECORDSREPLY = _descriptor.Descriptor(
  name='DataRecordsReply',
  full_name='com.datavorelabs.common.protos.DataRecordsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='records', full_name='com.datavorelabs.common.protos.DataRecordsReply.records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=716,
  serialized_end=795,
)


_LISTDATASOURCESREQUEST = _descriptor.Descriptor(
  name='ListDataSourcesRequest',
  full_name='com.datavorelabs.common.protos.ListDataSourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=821,
)


_DATASOURCERESULT = _descriptor.Descriptor(
  name='DataSourceResult',
  full_name='com.datavorelabs.common.protos.DataSourceResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='com.datavorelabs.common.protos.DataSourceResult.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.DataSourceResult.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=867,
)


_LISTDATASOURCESREPLY = _descriptor.Descriptor(
  name='ListDataSourcesReply',
  full_name='com.datavorelabs.common.protos.ListDataSourcesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataSources', full_name='com.datavorelabs.common.protos.ListDataSourcesReply.dataSources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=962,
)


_DATASOURCEUNIQUESREQUEST = _descriptor.Descriptor(
  name='DataSourceUniquesRequest',
  full_name='com.datavorelabs.common.protos.DataSourceUniquesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataSourceId', full_name='com.datavorelabs.common.protos.DataSourceUniquesRequest.dataSourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columns', full_name='com.datavorelabs.common.protos.DataSourceUniquesRequest.columns', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=1029,
)


_DATASOURCEMETAREQUEST = _descriptor.Descriptor(
  name='DataSourceMetaRequest',
  full_name='com.datavorelabs.common.protos.DataSourceMetaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataSourceId', full_name='com.datavorelabs.common.protos.DataSourceMetaRequest.dataSourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1031,
  serialized_end=1076,
)


_STRINGCOLUMNCONFIG = _descriptor.Descriptor(
  name='StringColumnConfig',
  full_name='com.datavorelabs.common.protos.StringColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.StringColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.StringColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier', full_name='com.datavorelabs.common.protos.StringColumnConfig.modifier', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ontology', full_name='com.datavorelabs.common.protos.StringColumnConfig.ontology', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1079,
  serialized_end=1252,
)


_NUMBERCOLUMNCONFIG = _descriptor.Descriptor(
  name='NumberColumnConfig',
  full_name='com.datavorelabs.common.protos.NumberColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.NumberColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.NumberColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1254,
  serialized_end=1310,
)


_TIMECOLUMNCONFIG = _descriptor.Descriptor(
  name='TimeColumnConfig',
  full_name='com.datavorelabs.common.protos.TimeColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.TimeColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.TimeColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dateFormat', full_name='com.datavorelabs.common.protos.TimeColumnConfig.dateFormat', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1312,
  serialized_end=1386,
)


_STATICSTRINGCOLUMNCONFIG = _descriptor.Descriptor(
  name='StaticStringColumnConfig',
  full_name='com.datavorelabs.common.protos.StaticStringColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.modifier', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ontology', full_name='com.datavorelabs.common.protos.StaticStringColumnConfig.ontology', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1389,
  serialized_end=1613,
)


_STATICNUMBERCOLUMNCONFIG = _descriptor.Descriptor(
  name='StaticNumberColumnConfig',
  full_name='com.datavorelabs.common.protos.StaticNumberColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.StaticNumberColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.StaticNumberColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.StaticNumberColumnConfig.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1615,
  serialized_end=1722,
)


_STATICTIMECOLUMNCONFIG = _descriptor.Descriptor(
  name='StaticTimeColumnConfig',
  full_name='com.datavorelabs.common.protos.StaticTimeColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.StaticTimeColumnConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='displayLabel', full_name='com.datavorelabs.common.protos.StaticTimeColumnConfig.displayLabel', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.datavorelabs.common.protos.StaticTimeColumnConfig.value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1828,
)


_COLUMNCONFIG = _descriptor.Descriptor(
  name='ColumnConfig',
  full_name='com.datavorelabs.common.protos.ColumnConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stringColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.stringColumnConfig', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.numberColumnConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.timeColumnConfig', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticStringColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.staticStringColumnConfig', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticNumberColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.staticNumberColumnConfig', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='staticTimeColumnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.staticTimeColumnConfig', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='columnConfig', full_name='com.datavorelabs.common.protos.ColumnConfig.columnConfig',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1831,
  serialized_end=2381,
)


_TIMETUPLECONFIG = _descriptor.Descriptor(
  name='TimeTupleConfig',
  full_name='com.datavorelabs.common.protos.TimeTupleConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeColumn', full_name='com.datavorelabs.common.protos.TimeTupleConfig.timeColumn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueColumn', full_name='com.datavorelabs.common.protos.TimeTupleConfig.valueColumn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2383,
  serialized_end=2441,
)


_DATALOADMAPPING = _descriptor.Descriptor(
  name='DataLoadMapping',
  full_name='com.datavorelabs.common.protos.DataLoadMapping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyColumns', full_name='com.datavorelabs.common.protos.DataLoadMapping.keyColumns', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueModifiers', full_name='com.datavorelabs.common.protos.DataLoadMapping.valueModifiers', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeColumns', full_name='com.datavorelabs.common.protos.DataLoadMapping.timeColumns', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='com.datavorelabs.common.protos.DataLoadMapping.frequency', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueLabelColumn', full_name='com.datavorelabs.common.protos.DataLoadMapping.valueLabelColumn', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeTuples', full_name='com.datavorelabs.common.protos.DataLoadMapping.timeTuples', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2444,
  serialized_end=2670,
)


_COLUMNSAMPLE = _descriptor.Descriptor(
  name='ColumnSample',
  full_name='com.datavorelabs.common.protos.ColumnSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columnName', full_name='com.datavorelabs.common.protos.ColumnSample.columnName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='com.datavorelabs.common.protos.ColumnSample.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2672,
  serialized_end=2722,
)


_ROWSAMPLE = _descriptor.Descriptor(
  name='RowSample',
  full_name='com.datavorelabs.common.protos.RowSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='com.datavorelabs.common.protos.RowSample.values', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2724,
  serialized_end=2799,
)


_DATASOURCEMETAREPLY = _descriptor.Descriptor(
  name='DataSourceMetaReply',
  full_name='com.datavorelabs.common.protos.DataSourceMetaReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dataSourceId', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.dataSourceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSourceName', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.dataSourceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columnConfigs', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.columnConfigs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataLoadMapping', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.dataLoadMapping', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampleData', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.sampleData', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columnSamples', full_name='com.datavorelabs.common.protos.DataSourceMetaReply.columnSamples', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2802,
  serialized_end=3144,
)


_LINEDEFINITION = _descriptor.Descriptor(
  name='LineDefinition',
  full_name='com.datavorelabs.common.protos.LineDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyPredicateIds', full_name='com.datavorelabs.common.protos.LineDefinition.keyPredicateIds', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyPath', full_name='com.datavorelabs.common.protos.LineDefinition.keyPath', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timePredicateId', full_name='com.datavorelabs.common.protos.LineDefinition.timePredicateId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valuePredicateId', full_name='com.datavorelabs.common.protos.LineDefinition.valuePredicateId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='com.datavorelabs.common.protos.LineDefinition.frequency', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSourceId', full_name='com.datavorelabs.common.protos.LineDefinition.dataSourceId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3147,
  serialized_end=3375,
)


_QUERYCOLUMN = _descriptor.Descriptor(
  name='QueryColumn',
  full_name='com.datavorelabs.common.protos.QueryColumn',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.datavorelabs.common.protos.QueryColumn.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='com.datavorelabs.common.protos.QueryColumn.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringFilter', full_name='com.datavorelabs.common.protos.QueryColumn.stringFilter', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberFilter', full_name='com.datavorelabs.common.protos.QueryColumn.numberFilter', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeFilter', full_name='com.datavorelabs.common.protos.QueryColumn.timeFilter', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3378,
  serialized_end=3669,
)


_LINEQUERY = _descriptor.Descriptor(
  name='LineQuery',
  full_name='com.datavorelabs.common.protos.LineQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='com.datavorelabs.common.protos.LineQuery.columns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3671,
  serialized_end=3744,
)


_DATASOURCEQUERYREQUEST = _descriptor.Descriptor(
  name='DataSourceQueryRequest',
  full_name='com.datavorelabs.common.protos.DataSourceQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lineQueries', full_name='com.datavorelabs.common.protos.DataSourceQueryRequest.lineQueries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3746,
  serialized_end=3834,
)

_OPTIONALSTRING.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_OPTIONALNUMBER.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_OPTIONALTIME.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_DATARECORD.fields_by_name['strings'].message_type = _OPTIONALSTRING
_DATARECORD.fields_by_name['numbers'].message_type = _OPTIONALNUMBER
_DATARECORD.fields_by_name['times'].message_type = _OPTIONALTIME
_DATARECORDSREPLY.fields_by_name['records'].message_type = _DATARECORD
_LISTDATASOURCESREPLY.fields_by_name['dataSources'].message_type = _DATASOURCERESULT
_STRINGCOLUMNCONFIG.fields_by_name['modifier'].enum_type = _PREDICATEMODIFIER
_STRINGCOLUMNCONFIG.fields_by_name['ontology'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICSTRINGCOLUMNCONFIG.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICSTRINGCOLUMNCONFIG.fields_by_name['modifier'].enum_type = _PREDICATEMODIFIER
_STATICSTRINGCOLUMNCONFIG.fields_by_name['ontology'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICNUMBERCOLUMNCONFIG.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_STATICTIMECOLUMNCONFIG.fields_by_name['value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_COLUMNCONFIG.fields_by_name['stringColumnConfig'].message_type = _STRINGCOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['numberColumnConfig'].message_type = _NUMBERCOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['timeColumnConfig'].message_type = _TIMECOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['staticStringColumnConfig'].message_type = _STATICSTRINGCOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['staticNumberColumnConfig'].message_type = _STATICNUMBERCOLUMNCONFIG
_COLUMNCONFIG.fields_by_name['staticTimeColumnConfig'].message_type = _STATICTIMECOLUMNCONFIG
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['stringColumnConfig'])
_COLUMNCONFIG.fields_by_name['stringColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['numberColumnConfig'])
_COLUMNCONFIG.fields_by_name['numberColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['timeColumnConfig'])
_COLUMNCONFIG.fields_by_name['timeColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['staticStringColumnConfig'])
_COLUMNCONFIG.fields_by_name['staticStringColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['staticNumberColumnConfig'])
_COLUMNCONFIG.fields_by_name['staticNumberColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_COLUMNCONFIG.oneofs_by_name['columnConfig'].fields.append(
  _COLUMNCONFIG.fields_by_name['staticTimeColumnConfig'])
_COLUMNCONFIG.fields_by_name['staticTimeColumnConfig'].containing_oneof = _COLUMNCONFIG.oneofs_by_name['columnConfig']
_DATALOADMAPPING.fields_by_name['frequency'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DATALOADMAPPING.fields_by_name['timeTuples'].message_type = _TIMETUPLECONFIG
_ROWSAMPLE.fields_by_name['values'].message_type = _OPTIONALSTRING
_DATASOURCEMETAREPLY.fields_by_name['columnConfigs'].message_type = _COLUMNCONFIG
_DATASOURCEMETAREPLY.fields_by_name['dataLoadMapping'].message_type = _DATALOADMAPPING
_DATASOURCEMETAREPLY.fields_by_name['sampleData'].message_type = _ROWSAMPLE
_DATASOURCEMETAREPLY.fields_by_name['columnSamples'].message_type = _COLUMNSAMPLE
_LINEDEFINITION.fields_by_name['keyPath'].message_type = _OPTIONALSTRING
_LINEDEFINITION.fields_by_name['frequency'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_QUERYCOLUMN.fields_by_name['type'].enum_type = _COLUMNTYPE
_QUERYCOLUMN.fields_by_name['stringFilter'].message_type = _OPTIONALSTRING
_QUERYCOLUMN.fields_by_name['numberFilter'].message_type = _OPTIONALNUMBER
_QUERYCOLUMN.fields_by_name['timeFilter'].message_type = _OPTIONALTIME
_LINEQUERY.fields_by_name['columns'].message_type = _QUERYCOLUMN
_DATASOURCEQUERYREQUEST.fields_by_name['lineQueries'].message_type = _LINEQUERY
DESCRIPTOR.message_types_by_name['OptionalString'] = _OPTIONALSTRING
DESCRIPTOR.message_types_by_name['OptionalNumber'] = _OPTIONALNUMBER
DESCRIPTOR.message_types_by_name['OptionalTime'] = _OPTIONALTIME
DESCRIPTOR.message_types_by_name['DataRecord'] = _DATARECORD
DESCRIPTOR.message_types_by_name['DataRecordsReply'] = _DATARECORDSREPLY
DESCRIPTOR.message_types_by_name['ListDataSourcesRequest'] = _LISTDATASOURCESREQUEST
DESCRIPTOR.message_types_by_name['DataSourceResult'] = _DATASOURCERESULT
DESCRIPTOR.message_types_by_name['ListDataSourcesReply'] = _LISTDATASOURCESREPLY
DESCRIPTOR.message_types_by_name['DataSourceUniquesRequest'] = _DATASOURCEUNIQUESREQUEST
DESCRIPTOR.message_types_by_name['DataSourceMetaRequest'] = _DATASOURCEMETAREQUEST
DESCRIPTOR.message_types_by_name['StringColumnConfig'] = _STRINGCOLUMNCONFIG
DESCRIPTOR.message_types_by_name['NumberColumnConfig'] = _NUMBERCOLUMNCONFIG
DESCRIPTOR.message_types_by_name['TimeColumnConfig'] = _TIMECOLUMNCONFIG
DESCRIPTOR.message_types_by_name['StaticStringColumnConfig'] = _STATICSTRINGCOLUMNCONFIG
DESCRIPTOR.message_types_by_name['StaticNumberColumnConfig'] = _STATICNUMBERCOLUMNCONFIG
DESCRIPTOR.message_types_by_name['StaticTimeColumnConfig'] = _STATICTIMECOLUMNCONFIG
DESCRIPTOR.message_types_by_name['ColumnConfig'] = _COLUMNCONFIG
DESCRIPTOR.message_types_by_name['TimeTupleConfig'] = _TIMETUPLECONFIG
DESCRIPTOR.message_types_by_name['DataLoadMapping'] = _DATALOADMAPPING
DESCRIPTOR.message_types_by_name['ColumnSample'] = _COLUMNSAMPLE
DESCRIPTOR.message_types_by_name['RowSample'] = _ROWSAMPLE
DESCRIPTOR.message_types_by_name['DataSourceMetaReply'] = _DATASOURCEMETAREPLY
DESCRIPTOR.message_types_by_name['LineDefinition'] = _LINEDEFINITION
DESCRIPTOR.message_types_by_name['QueryColumn'] = _QUERYCOLUMN
DESCRIPTOR.message_types_by_name['LineQuery'] = _LINEQUERY
DESCRIPTOR.message_types_by_name['DataSourceQueryRequest'] = _DATASOURCEQUERYREQUEST
DESCRIPTOR.enum_types_by_name['PredicateModifier'] = _PREDICATEMODIFIER
DESCRIPTOR.enum_types_by_name['ColumnType'] = _COLUMNTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OptionalString = _reflection.GeneratedProtocolMessageType('OptionalString', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALSTRING,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.OptionalString)
  })
_sym_db.RegisterMessage(OptionalString)

OptionalNumber = _reflection.GeneratedProtocolMessageType('OptionalNumber', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALNUMBER,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.OptionalNumber)
  })
_sym_db.RegisterMessage(OptionalNumber)

OptionalTime = _reflection.GeneratedProtocolMessageType('OptionalTime', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALTIME,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.OptionalTime)
  })
_sym_db.RegisterMessage(OptionalTime)

DataRecord = _reflection.GeneratedProtocolMessageType('DataRecord', (_message.Message,), {
  'DESCRIPTOR' : _DATARECORD,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataRecord)
  })
_sym_db.RegisterMessage(DataRecord)

DataRecordsReply = _reflection.GeneratedProtocolMessageType('DataRecordsReply', (_message.Message,), {
  'DESCRIPTOR' : _DATARECORDSREPLY,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataRecordsReply)
  })
_sym_db.RegisterMessage(DataRecordsReply)

ListDataSourcesRequest = _reflection.GeneratedProtocolMessageType('ListDataSourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREQUEST,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.ListDataSourcesRequest)
  })
_sym_db.RegisterMessage(ListDataSourcesRequest)

DataSourceResult = _reflection.GeneratedProtocolMessageType('DataSourceResult', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERESULT,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceResult)
  })
_sym_db.RegisterMessage(DataSourceResult)

ListDataSourcesReply = _reflection.GeneratedProtocolMessageType('ListDataSourcesReply', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREPLY,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.ListDataSourcesReply)
  })
_sym_db.RegisterMessage(ListDataSourcesReply)

DataSourceUniquesRequest = _reflection.GeneratedProtocolMessageType('DataSourceUniquesRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEUNIQUESREQUEST,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceUniquesRequest)
  })
_sym_db.RegisterMessage(DataSourceUniquesRequest)

DataSourceMetaRequest = _reflection.GeneratedProtocolMessageType('DataSourceMetaRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEMETAREQUEST,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceMetaRequest)
  })
_sym_db.RegisterMessage(DataSourceMetaRequest)

StringColumnConfig = _reflection.GeneratedProtocolMessageType('StringColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _STRINGCOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.StringColumnConfig)
  })
_sym_db.RegisterMessage(StringColumnConfig)

NumberColumnConfig = _reflection.GeneratedProtocolMessageType('NumberColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _NUMBERCOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.NumberColumnConfig)
  })
_sym_db.RegisterMessage(NumberColumnConfig)

TimeColumnConfig = _reflection.GeneratedProtocolMessageType('TimeColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _TIMECOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.TimeColumnConfig)
  })
_sym_db.RegisterMessage(TimeColumnConfig)

StaticStringColumnConfig = _reflection.GeneratedProtocolMessageType('StaticStringColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICSTRINGCOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.StaticStringColumnConfig)
  })
_sym_db.RegisterMessage(StaticStringColumnConfig)

StaticNumberColumnConfig = _reflection.GeneratedProtocolMessageType('StaticNumberColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICNUMBERCOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.StaticNumberColumnConfig)
  })
_sym_db.RegisterMessage(StaticNumberColumnConfig)

StaticTimeColumnConfig = _reflection.GeneratedProtocolMessageType('StaticTimeColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICTIMECOLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.StaticTimeColumnConfig)
  })
_sym_db.RegisterMessage(StaticTimeColumnConfig)

ColumnConfig = _reflection.GeneratedProtocolMessageType('ColumnConfig', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNCONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.ColumnConfig)
  })
_sym_db.RegisterMessage(ColumnConfig)

TimeTupleConfig = _reflection.GeneratedProtocolMessageType('TimeTupleConfig', (_message.Message,), {
  'DESCRIPTOR' : _TIMETUPLECONFIG,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.TimeTupleConfig)
  })
_sym_db.RegisterMessage(TimeTupleConfig)

DataLoadMapping = _reflection.GeneratedProtocolMessageType('DataLoadMapping', (_message.Message,), {
  'DESCRIPTOR' : _DATALOADMAPPING,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataLoadMapping)
  })
_sym_db.RegisterMessage(DataLoadMapping)

ColumnSample = _reflection.GeneratedProtocolMessageType('ColumnSample', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNSAMPLE,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.ColumnSample)
  })
_sym_db.RegisterMessage(ColumnSample)

RowSample = _reflection.GeneratedProtocolMessageType('RowSample', (_message.Message,), {
  'DESCRIPTOR' : _ROWSAMPLE,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.RowSample)
  })
_sym_db.RegisterMessage(RowSample)

DataSourceMetaReply = _reflection.GeneratedProtocolMessageType('DataSourceMetaReply', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEMETAREPLY,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceMetaReply)
  })
_sym_db.RegisterMessage(DataSourceMetaReply)

LineDefinition = _reflection.GeneratedProtocolMessageType('LineDefinition', (_message.Message,), {
  'DESCRIPTOR' : _LINEDEFINITION,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.LineDefinition)
  })
_sym_db.RegisterMessage(LineDefinition)

QueryColumn = _reflection.GeneratedProtocolMessageType('QueryColumn', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCOLUMN,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.QueryColumn)
  })
_sym_db.RegisterMessage(QueryColumn)

LineQuery = _reflection.GeneratedProtocolMessageType('LineQuery', (_message.Message,), {
  'DESCRIPTOR' : _LINEQUERY,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.LineQuery)
  })
_sym_db.RegisterMessage(LineQuery)

DataSourceQueryRequest = _reflection.GeneratedProtocolMessageType('DataSourceQueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEQUERYREQUEST,
  '__module__' : 'dv_pyclient.grpc.dataSources_pb2'
  # @@protoc_insertion_point(class_scope:com.datavorelabs.common.protos.DataSourceQueryRequest)
  })
_sym_db.RegisterMessage(DataSourceQueryRequest)


_OPTIONALSTRING._options = None
_OPTIONALNUMBER._options = None
_OPTIONALTIME._options = None
_DATARECORD.fields_by_name['strings']._options = None
_DATARECORD.fields_by_name['numbers']._options = None
_DATARECORD.fields_by_name['times']._options = None

_REMOTEDATASOURCE = _descriptor.ServiceDescriptor(
  name='RemoteDataSource',
  full_name='com.datavorelabs.common.protos.RemoteDataSource',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3953,
  serialized_end=4501,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDataSources',
    full_name='com.datavorelabs.common.protos.RemoteDataSource.ListDataSources',
    index=0,
    containing_service=None,
    input_type=_LISTDATASOURCESREQUEST,
    output_type=_LISTDATASOURCESREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='dataSourceUniques',
    full_name='com.datavorelabs.common.protos.RemoteDataSource.dataSourceUniques',
    index=1,
    containing_service=None,
    input_type=_DATASOURCEUNIQUESREQUEST,
    output_type=_DATARECORDSREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='sampleDataSourceMeta',
    full_name='com.datavorelabs.common.protos.RemoteDataSource.sampleDataSourceMeta',
    index=2,
    containing_service=None,
    input_type=_DATASOURCEMETAREQUEST,
    output_type=_DATASOURCEMETAREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='dataSourceQuery',
    full_name='com.datavorelabs.common.protos.RemoteDataSource.dataSourceQuery',
    index=3,
    containing_service=None,
    input_type=_DATASOURCEQUERYREQUEST,
    output_type=_DATARECORDSREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_REMOTEDATASOURCE)

DESCRIPTOR.services_by_name['RemoteDataSource'] = _REMOTEDATASOURCE

# @@protoc_insertion_point(module_scope)



from dv_pyclient.grpc.datavore import dataSources_pb2 as api
from dv_pyclient.grpc.datavore import dataSources_pb2_grpc as rpc

from sqlite3 import dbapi2 as sqlite
import psycopg2 as postgres

sampleDb = 'example.db'
txns = [
    ('2006-01-01', 'BUY', 'RHAT', 100, 35.00, 'USD'),
    ('2006-02-01', 'BUY', 'RHAT', 200, 32.00, 'USD'),
    ('2006-03-01', 'BUY', 'RHAT', 300, 34.00, 'USD'),
    ('2006-04-01', 'BUY', 'RHAT', 400, 35.10, 'USD'),
    ('2006-05-01', 'BUY', 'RHAT', 500, 35.20, 'USD'),
    ('2006-06-01', 'BUY', 'RHAT', 600, 35.30, 'USD'),

    ('2006-01-02', 'SELL', 'RHAT', 100, 35.60, 'USD'),
    ('2006-02-02', 'SELL', 'RHAT', 200, 32.60, 'USD'),
    ('2006-03-02', 'SELL', 'RHAT', 300, 34.60, 'USD'),
    ('2006-04-02', 'SELL', 'RHAT', 400, 35.60, 'USD'),
    ('2006-05-02', 'SELL', 'RHAT', 500, 35.60, 'USD'),
    ('2006-06-02', 'SELL', 'RHAT', 600, 35.60, 'USD'),

    ('2006-01-01', 'BUY', 'MSFT', 1100, 135.00, 'USD'),
    ('2006-02-01', 'BUY', 'MSFT', 1200, 132.00, 'USD'),
    ('2006-03-01', 'BUY', 'MSFT', 1300, 134.00, 'USD'),
    ('2006-04-01', 'BUY', 'MSFT', 1400, 135.10, 'USD'),
    ('2006-05-01', 'BUY', 'MSFT', 1500, 135.20, 'USD'),
    ('2006-06-01', 'BUY', 'MSFT', 1600, 135.30, 'USD'),

    ('2006-01-02', 'SELL', 'MSFT', 1100, 135.60, 'USD'),
    ('2006-02-02', 'SELL', 'MSFT', 1200, 132.60, 'USD'),
    ('2006-03-02', 'SELL', 'MSFT', 1300, 134.60, 'USD'),
    ('2006-04-02', 'SELL', 'MSFT', 1400, 135.60, 'USD'),
    ('2006-05-02', 'SELL', 'MSFT', 1500, 135.60, 'USD'),
    ('2006-06-02', 'SELL', 'MSFT', 1600, 135.60, 'USD'),
]

def add_fake_data(conn, query_param_type):
    c = conn.cursor()
    c.execute('''DROP TABLE IF EXISTS stocks ''')
    c.execute('''CREATE TABLE stocks(
        date date, 
        trans text, 
        symbol text, 
        qty real, 
        price real,
        currency text
    )''')
    param = "?" if query_param_type == 'qmark' else "%s"
    c.executemany(f'INSERT INTO stocks VALUES ({param}, {param}, {param}, {param}, {param}, {param})', txns)
    c.close()
    conn.commit()


def generateConfig(sql, con):
    c = con.cursor()
    c.execute(sql)
    meta = [description for description in c.description]
    print(meta)
    batch = c.fetchmany(3)
    while True:
        if not batch:
            break
        for row in batch:
            print(row)
        batch = c.fetchmany(3)
    c.close()


if __name__ == '__main__':

    pg_conn = postgres.connect("dbname='postgres' user='postgres' host='localhost' "
                               "password='mysecretpassword'")
    pg_query_param_type = postgres.paramstyle
    add_fake_data(pg_conn, pg_query_param_type)
    generateConfig("select * from stocks", pg_conn, pg_query_param_type)

    sqlite_query_param_type = sqlite.paramstyle
    sqlite_conn = sqlite.connect(sampleDb)
    add_fake_data(sqlite_conn, sqlite_query_param_type)
    generateConfig("select * from stocks", sqlite_conn)





'''Main module.'''

import io
import json
import tempfile
import ndjson
import requests
import jwt
import getpass
import numpy as np
import pandas as pd
import copy

from pandas.core.dtypes.common import (
    is_string_dtype,
    is_numeric_dtype,
    is_datetime64_any_dtype,
)


def __generate_meta(lines_in):
    key_columns = []
    time_columns = []
    value_columns = []
    dtype = []
    for line in lines_in:
        for key in line['keys']:
            key_col_name = key['label']
            if key_col_name not in key_columns:
                key_columns.append(key_col_name)
                dtype.append(np.str)
        time_col_name = line['time']
        if time_col_name not in time_columns:
            time_columns.append(time_col_name)
            dtype.append(np.int64)
        value_col_name = line['value']
        if value_col_name not in value_columns:
            value_columns.append(value_col_name)
            dtype.append(np.float64)
    return key_columns, time_columns, value_columns, dtype


def __df_empty(columns, dtypes, index=None):
    assert len(columns) == len(dtypes)
    df = pd.DataFrame(index=index)
    for c, d in zip(columns, dtypes):
        df[c] = pd.Series(dtype=d)
    return df


def __getColumnTypeOptions(dType):
    if (is_numeric_dtype(dType)):
        return {
            'dataType': 'NumberColumnConfig',
        }
    if (is_string_dtype(dType)):
        return {
            'dataType': 'StringColumnConfig',
        }
    if (is_datetime64_any_dtype(dType)):
        return {
            'dateFormat': 'ISO_DATE_TIME',
            'dataType': 'TimeColumnConfig',
        }
    raise Exception(f'Unsupprted dType: {dType}')


def __getColumnConfigs(df):
    columnConfigs = []
    for name, dType in df.dtypes.items():
        baseConfig = __getColumnTypeOptions(dType)
        baseConfig.update({
            'name': name,
            'displayLabel': name,
        })
        columnConfigs.append(baseConfig)
    return columnConfigs


def __csvFileSettings(columnConfigs):
    return {
        'filePath': 'from dataframe',
        'delimiter': ',',
        'lineSeparator': '\n',
        'quote': '"',
        'quoteEscape': '"',
        'columnConfigs': columnConfigs,
    }


def __dataLoadMapping(keyColumns, valueModifiers, timeColumns, frequency, valueLabelColumn, timeTuples):
    return {
        'keyColumns': keyColumns,
        'valueModifiers': valueModifiers,
        'timeColumns': timeColumns,
        'frequency': frequency,
        'valueLabelColumn': valueLabelColumn,
        'timeTuples': timeTuples,
    }


def __datasourceMeta(datasourceId, datasource, publisher, dataset, readGroups):
    return {
        'DATA_SOURCE_ID': datasourceId,
        'DATA_SOURCE': datasource,
        'PUBLISHER': publisher,
        'DATASET': dataset,
        'readGroups': readGroups,
    }


def __isTimeDataType(dataType):
    return dataType in frozenset(['TimeColumnConfig', 'StaticTimeConfig'])


def __isStringDataType(dataType):
    return dataType in frozenset(['StringColumnConfig', 'StaticStringConfig'])


def __isNumberDataType(dataType):
    return dataType in frozenset(['NumberColumnConfig', 'StaticNumberConfig'])


def __isStaticDataType(dataType):
    return dataType in frozenset(['StaticTimeConfig', 'StaticStringConfig', 'StaticNumberConfig'])


def __getDataLoadMappings(columnConfigs, valueModifiers):
    stringColumns = list(
        filter(lambda c: __isStringDataType(c['dataType']), columnConfigs))
    keyColumns = list(filter(lambda s: not (s in valueModifiers), stringColumns))
    timeColumns = list(
        filter(lambda c: __isTimeDataType(c['dataType']), columnConfigs))
    valueColumns = list(
        filter(lambda c: __isNumberDataType(c['dataType']), columnConfigs))
    timeTuples = []
    for v in valueColumns:
        for t in timeColumns:
            timeTuples.append(
                {'timeColumn': t['name'], 'valueColumn': v['name']}
            )

    return stringColumns, keyColumns, timeColumns, valueColumns, timeTuples


def __generateDataSourceLoaderConfig(df, userName, dataSourceId, frequency, valueModifiers, valueLabelColumn,
                                     sampleData=None, columnSamples=None):
    columnConfigs = __getColumnConfigs(df)
    stringColumns, keyColumns, timeColumns, valueColumns, timeTuples = __getDataLoadMappings(columnConfigs, valueModifiers)
    csvConfig = {
        'generated': True,
        'sourceSettings': __csvFileSettings(columnConfigs),
        'mapping': __dataLoadMapping(
            keyColumns=list(map(lambda i: i['name'], keyColumns)),
            timeColumns=list(map(lambda i: i['name'], timeColumns)),
            valueLabelColumn=list(map(lambda i: i['name'], valueLabelColumn)),
            valueModifiers=valueModifiers,
            frequency=frequency,
            timeTuples=timeTuples
        ),
        'sampleData': sampleData,
        'columnSamples': columnSamples,
        'datasource': __datasourceMeta(dataSourceId, 'datasource', userName, 'dataset', []),
    }
    return {
        'type': 'CsvDataLoaderConfig',
        'dataSource': {
            'docType': 'DataSource',
            'id': dataSourceId,
        },
        'strategy': 'Overwrite',
        'loaderConfig': csvConfig,
        'inputs': {}
    }


def load_df(lines_in) -> pd.DataFrame:
    '''
    Load lines into a dataframe
    Returns a DataFrame
    '''
    key_columns, time_columns, value_columns, dtype = __generate_meta(lines_in)
    df = __df_empty(list(key_columns + time_columns + value_columns), dtype)
    for line in lines_in:
        row_keys = {}
        time_key = line['time']
        value_key = line['value']
        for key in line['keys']:
            row_keys[key['label']] = key['value']
        for data_point in line['data']:
            base = copy.copy(row_keys)
            base[time_key] = pd.to_datetime(data_point[0], unit='ms')
            base[value_key] = data_point[1]
            df = df.append(base, ignore_index=True)
    index_columns = list(key_columns + time_columns)
    return df.pivot_table(
        index=index_columns
    ).reset_index()


class Session:
    user_name = None
    user = None
    token = None
    env_conf = None

    def __init__(self, user_name, env_conf):
        self.user_name = user_name
        self.env_conf = env_conf

    def set_user(self, user):
        self.user = user

    def set_token(self, token):
        self.token = token


def login(user_name=None, env_conf=None, password=None):
    '''
    Returns a valid datavore Session object
    '''
    if password == None:
        password = getpass.getpass(
            prompt=f'Enter password for user {user_name} :')

    if user_name is not None and password is not None and env_conf is not None:
        res = requests.get(
            f'{env_conf["authDomain"]}/login', auth=(user_name, password))
        if res.status_code == 200:
            result_json = res.json()
            token = result_json['nextToken']
            user = jwt.decode(token, verify=False)
            print(f'Login success for {user["fullName"]}\n')
            result = Session(user_name, env_conf)
            result.set_user(user)
            result.set_token(token)
            return result
        else:
            raise Exception(res.status_code, res.content.decode('ascii'))
    else:
        print('Requires username, password and data_config from Datavore UI')


def get_data(session: Session, step_info=None):
    '''
    1. Make request using token.
    1a. if response is 200OK, return data as pandas frame
    1b. if response 401Unauthorized try login and return data frame
    1c. if response is any other
            throw exception
    Session that contains information to re-authenticate if required.
    :param session:
    :param step_info: Some JSON to post
    :return:
    '''
    auth_header = {
        'Authorization': 'Bearer %s' % session.token,
        'Content-type': 'application/json',
    }

    res = requests.post(
        f'{session.env_conf["execDomain"]}/get-lines', json=step_info, headers=auth_header)
    if res.status_code == 200:
        payload = res.json(cls=ndjson.Decoder)
        return payload
    elif res.status_code == 401:
        session = login(session.user_name, session.env_conf)
        return get_data(session, step_info)
    else:
        raise Exception(res.status_code, res.content.decode('ascii'))


def __setDatasourceLoaderConfig(session: Session, dataSourceId, loaderConfig):
    auth_header = {
        'Authorization': 'Bearer %s' % session.token,
        'Content-type': 'application/json',
    }
    url = f'{session.env_conf["apiDomain"]}/txns/datasource/{dataSourceId}/loader'
    res = requests.post(url, headers=auth_header, json=loaderConfig)
    if res.status_code == 200:
        return res
    else:
        raise Exception(res.status_code, res.content.decode('ascii'))

def __getDatasourceLoaderConfig(session: Session, dataSourceId):
    auth_header = {
        'Authorization': 'Bearer %s' % session.token,
        'Content-type': 'application/json',
    }
    url = f'{session.env_conf["apiDomain"]}/txns/datasource/{dataSourceId}/loader'
    res = requests.get(url, headers=auth_header)
    if res.status_code == 200:
        return res.json()['payload']['document']['config']
    else:
        raise Exception(res.status_code, res.content.decode('ascii'))

def getPublishStatus(session: Session, dataSourceId):
    auth_header = {
        'Authorization': 'Bearer %s' % session.token,
        'Content-type': 'application/json',
    }
    url = f'{session.env_conf["apiDomain"]}/txns/datasource/{dataSourceId}/loader'
    res = requests.get(url, headers=auth_header)
    if res.status_code == 200:
        statusJson = res.json()['payload']['document']['status']

        if statusJson.get('status') == 'rejected':
            return {
                'status': statusJson.get('status'),
                'reason': statusJson.get('reason')
            }

        return { 'status': statusJson.get('status') }
    else:
        raise Exception(res.status_code, res.content.decode('ascii'))

def __getPreSignedUrl(session: Session, dataSourceId):
    auth_header = {
        'Authorization': 'Bearer %s' % session.token,
        'Content-type': 'application/json',
    }
    params = {'dataSourceId': dataSourceId, 'extension': '.csv'}
    url = f'{session.env_conf["apiDomain"]}/dataload/csvUploadUrl'
    res = requests.get(url, headers=auth_header, params=params)
    if res.status_code == 200:
        return res.json()['payload']['presignedUrl']
    else:
        raise Exception(res.status_code, res.content.decode('ascii'))


def __cancelCurrentLoad(session: Session, dataSourceId):
    auth_header = {
        'Authorization': 'Bearer %s' % session.token,
        'Content-type': 'application/json',
    }
    url = f'{session.env_conf["apiDomain"]}/task/cancel/DATALOADER_{dataSourceId}'
    res = requests.delete(url, headers=auth_header)
    if res.status_code == 200:
        return res.json()['payload']
    else:
        raise Exception(res.status_code, res.content.decode('ascii'))


def __getColumnsByName(columnConfigs):
    return dict(
        map(lambda x: (x['name'], x), columnConfigs)
    )


def __validateLoaderConfig(loaderConfig, df=None):
    csvConfig = loaderConfig.get('loaderConfig')
    if not csvConfig:
        raise Exception('Empty loader config')

    # Check mapping
    mapping = csvConfig.get('mapping')
    if not mapping.get('timeColumns'):
        raise Exception('Loader config requires non-empty time columns.')

    # Check time tuples nonempty
    if not mapping.get('timeTuples'):
        raise Exception('Time tuples empty. No column loaded.')

    columnByName = __getColumnsByName(csvConfig['sourceSettings']['columnConfigs'])

    # Collectors for referenced cols
    requiredFields = set()

    # Check all columns are correct types and all are defined
    for field in mapping['keyColumns']:
        requiredFields.add(field)
        if not columnByName.get(field):
            raise Exception(f'key column {field} not found.')

        fieldType = columnByName[field]['dataType']
        if not __isStringDataType(fieldType):
            raise Exception(f'key column {field} must be a string, got {fieldType}.')

    # Check all value label are correct types and all are defined
    for field in mapping['valueLabelColumn']:
        requiredFields.add(field)
        if not columnByName.get(field):
            raise Exception(f'value label {field} not found.')

        fieldType = columnByName[field]['dataType']
        if not __isStringDataType(fieldType):
            raise Exception(f'value label {field} must be a string, got {fieldType}.')

    # Check all time columns label are correct types and all are defined
    for field in mapping['timeColumns']:
        requiredFields.add(field)
        if not columnByName.get(field):
            raise Exception(f'time column {field} not found.')

        fieldType = columnByName[field]['dataType']
        if not __isTimeDataType(fieldType):
            raise Exception(f'time column {field} must be a time, got {fieldType}.')

    # Check all time tuples
    for timeTuple in mapping['timeTuples']:
        requiredFields.add(timeTuple['timeColumn'])
        requiredFields.add(timeTuple['valueColumn'])

        if not columnByName.get(timeTuple['timeColumn']):
            raise Exception(f'time column in tuple {str(timeTuple)} not found.')

        timeType = columnByName[timeTuple['timeColumn']]['dataType']
        if not __isTimeDataType(timeType):
            raise Exception(f'time column in tuple {str(timeTuple)} must be a time, got {timeType}.')

        if not columnByName.get(timeTuple['valueColumn']):
            raise Exception(f'value column in tuple {str(timeTuple)} not found.')

        valueType = columnByName.get(timeTuple['valueColumn'])['dataType']
        if not __isNumberDataType(valueType):
            raise Exception(f'value column in tuple {str(timeTuple)} must be a number, got {valueType}.')

    # Check data frame fields and types
    if not df is None:
        dfColumnsByName = __getColumnsByName(__getColumnConfigs(df))
        for keyField in filter(lambda x: not __isStaticDataType(columnByName[x]['dataType']), requiredFields):
            requiredType = columnByName[keyField]['dataType']
            if not dfColumnsByName.get(keyField):
                raise Exception(f'data frame missing required field: {keyField} of type: {requiredType}')

            if dfColumnsByName[keyField]['dataType'] != requiredType:
                raise Exception(
                    f'data frame field {keyField} must be of type {requiredType}. Got {dfColumnsByName[keyField]["dataType"]}')

    return True


def publish(session: Session, dataSourceId, df):
    # Get the current loader config
    currentConfig = __getDatasourceLoaderConfig(session, dataSourceId)

    # Validate the config against the dataframe
    if not __validateLoaderConfig(currentConfig, df):
        raise Exception('Could not validate config.')

    # Cancel load if it exists
    try:
        __cancelCurrentLoad(session, dataSourceId)
    except:
        print('No job to cancel. Continuing.')
        # @todo: log debug here -- exception if never loaded before

    # Generate upload url
    uploadUrl = __getPreSignedUrl(session, dataSourceId)

    print('Uploading data frame...')

    # Update the config with the URL @todo: use patch so we don't send the entire data brick back up :/
    # currentConfig['uploadUrl'] = uploadUrl
    # __setDatasourceLoaderConfig(session, dataSourceId, currentConfig)

    # Put data to the uploadUrl
    retries = 2
    with tempfile.NamedTemporaryFile(mode='r+') as temp:
        df.to_csv(temp.name, index=False, date_format='%Y-%m-%dT%H:%M:%SZ')

        while retries > 0:
            with open(temp.name, mode='rb') as csvFile:
                res = requests.put(uploadUrl, data=csvFile)
                if res.status_code == 200:
                    print('Data frame uploaded. Datavore load started.')
                    return res
                elif res.status_code == 401:
                    retries -= 1
                    print(f'Session upload error. Log in again. Attempts remaining: {retries}')
                    session = login(session.user_name, session.env_conf)
                else:
                    raise Exception(res.status_code, res.content.decode('ascii'))

        # Ran out of retries and never managed to upload :(
        raise Exception('Failed to upload.')

def __toStrNone(s):
    if s is None:
        return None
    return str(s)

def __getDataFrameSample(df, colToSample=25, rowsToSample=25):
    # get only string columns -- @todo: is object fine? data frames with mixed types are object (so, strings with null)
    stringsOnly = list(
        df.select_dtypes(include=['category', 'object']).columns
    )

    # get a distinct on strings sample
    sampleData = df.drop_duplicates(subset=stringsOnly).sample(min(len(df), rowsToSample))

    # format dates as iso strings
    datesOnly = list(
        sampleData.select_dtypes(include=[np.datetime64]).columns
    )
    sampleData[datesOnly] = sampleData[datesOnly].applymap(lambda x: x.isoformat())

    # first 25 unique non-null values of column c
    columnSamples = {}
    for c in df.columns:
        sample = df[c].dropna().sample(colToSample, replace=True)
        columnSamples[c] = list(map(str, sample))

    sampleValues = sampleData.where(pd.notnull(df), None).applymap(__toStrNone).values.tolist()

    # Project values
    return {
        'sampleData': sampleValues,
        'columnSamples': columnSamples
    }


def setDataSourceSample(session: Session, dataSourceId, df):
    # get the samples
    sample = __getDataFrameSample(df)
    # generate a loaderConfig
    loaderConfig = __generateDataSourceLoaderConfig(
        df,
        session.user_name,
        dataSourceId,
        frequency=None,
        valueModifiers=[],
        valueLabelColumn=[],
        sampleData=sample['sampleData'],
        columnSamples=sample['columnSamples']
    )
    # validate the loaderConfig
    __validateLoaderConfig(loaderConfig)

    # save the loaderConfig
    out = __setDatasourceLoaderConfig(session, dataSourceId, loaderConfig)
    print('Sample uploaded. Go to the Datavore client to review')
    return out



from dv_pyclient.grpc.datavore import dataSources_pb2 as api
from dv_pyclient.grpc.datavore import dataSources_pb2_grpc as rpc
import grpc
import google.protobuf.wrappers_pb2 as proto


def listRequest(stub):
    ds_list = stub.ListDataSources(request=api.ListDataSourcesRequest())
    print(ds_list)


def sampleDataSourceMeta(stub, ds_id):
    meta = stub.sampleDataSourceMeta(request=api.DataSourceMetaRequest(dataSourceId=ds_id))
    print(meta)


def dataSourceUniques(stub):
    request = api.DataSourceUniquesRequest(dataSourceId="ds_id_test_grpc", columns=['trans', 'symbol', 'currency'])
    res = stub.dataSourceUniques(request=request)
    for batch in res:
        print(batch)

def dataSourceQuery(stub):
    source_cols = ["date", "trans", "symbol", "qty", "currency"]
    column_types = ["Time", "String", "String", "Number", "String"]
    filters = [[], ["BUY"], ["RHAT"], [], [], ["USD"]]
    query_columns = []
    for col, type, filter in zip(source_cols, column_types, filters):
        stringFilter, numberFilter, timeFilter = [], [], []
        if type == "String":
            stringFilter = list(map(lambda f: api.OptionalString(value=proto.StringValue(value=f)), filter))
        if type == "Number":
            numberFilter = list(map(lambda f: api.OptionalNumber(value=proto.DoubleValue(value=f)), filter))
        if type == "Time":
            timeFilter = list(map(lambda f: api.OptionalTime(value=proto.Int64Value(value=f)), filter))

        query_columns.append(
            api.QueryColumn(
                name=col,
                type=type,
                stringFilter=stringFilter,
                numberFilter=numberFilter,
                timeFilter=timeFilter
            )
        )
    line_query = api.LineQuery(columns=query_columns)
    request = api.DataSourceQueryRequest(
        lineQueries=[line_query]
    )
    res = stub.dataSourceQuery(request)
    for batch in res:
        print(batch)


def run_main():
    ## Setup channel
    channel = grpc.insecure_channel('localhost:50051')
    rpc_stub = rpc.RemoteDataSourceStub(channel)

    # List datasources request
    listRequest(rpc_stub)

    # Sample datasource meta request
    sampleDataSourceMeta(rpc_stub, ds_id="ds_id_test_grpc")
    try:
        sampleDataSourceMeta(rpc_stub, ds_id="ds_id_test")
    except grpc._channel._InactiveRpcError as rpcErr:
        print(f"Got error {rpcErr}")

    ## datasource uniques
    dataSourceUniques(rpc_stub)

    dataSourceQuery(rpc_stub)


if __name__ == '__main__':
    run_main()



from dv_pyclient.grpc.datavore import dataSources_pb2 as api
from dv_pyclient.grpc.datavore import dataSources_pb2_grpc as rpc
from dv_pyclient.grpc import datasource_util as util
import grpc
from io import StringIO
import pandas as pd
import numpy as np
import google.protobuf.wrappers_pb2 as proto
import time

# Some import parameters
ds_id = "ds_id_test_grpc"
ds_name = "Test Datasource (grpc)"

sample_data = """
date,trans,symbol,qty,price,currency
2006-01-01,BUY,RHAT,100,35.00,USD
2006-02-01,BUY,RHAT,200,32.00,USD
2006-03-01,BUY,RHAT,300,34.00,USD
2006-04-01,BUY,RHAT,400,35.10,USD
2006-05-01,BUY,RHAT,500,35.20,USD
2006-06-01,BUY,RHAT,600,35.30,USD
2006-01-02,SELL,RHAT,100,35.60,USD
2006-02-02,SELL,RHAT,200,32.60,USD
2006-03-02,SELL,RHAT,300,34.60,USD
2006-04-02,SELL,RHAT,400,35.60,USD
2006-05-02,SELL,RHAT,500,35.60,USD
2006-06-02,SELL,RHAT,600,35.60,USD
2006-01-01,BUY,MSFT,1100,135.00,USD
2006-02-01,BUY,MSFT,1200,132.00,USD
2006-03-01,BUY,MSFT,1300,134.00,USD
2006-04-01,BUY,MSFT,1400,135.10,USD
2006-05-01,BUY,MSFT,1500,135.20,USD
2006-06-01,BUY,MSFT,1600,135.30,USD
2006-01-02,SELL,MSFT,1100,135.60,USD
2006-02-02,SELL,MSFT,1200,132.60,USD
2006-03-02,SELL,MSFT,1300,134.60,USD
2006-04-02,SELL,MSFT,1400,135.60,USD
2006-05-02,SELL,MSFT,1500,135.60,USD
2006-06-02,SELL,MSFT,1600,135.60,USD
"""

class TestDatasource(rpc.RemoteDataSourceServicer):

    def __init__(self):
        super()
        self.df = pd.read_csv(StringIO(sample_data), sep=",", parse_dates=['date'])

    def ListDataSources(self, request: api.ListDataSourcesRequest, context) -> api.ListDataSourcesReply:
        datasources = [api.DataSourceResult(id=ds_id, name=ds_name)]
        return api.ListDataSourcesReply(dataSources=datasources)

    def dataSourceQuery(self, request: api.DataSourceQueryRequest, context):
        line_queries = request.lineQueries
        if len(line_queries) == 0:
            context.set_code(grpc.StatusCode.INVALID_ARGUMENT)
            context.set_details(f'No lines specified in request')
            raise RuntimeError('Invalid dataSourceQuery request')
        yield from util.dataSourceQueryStreamPandas(self.df, request)

    def dataSourceUniques(self, request: api.DataSourceUniquesRequest, context):
        if request.dataSourceId != ds_id:
            context.set_code(grpc.StatusCode.INVALID_ARGUMENT)
            context.set_details(f'Datasource id does not equal requested id: {request.dataSourceId}')
            raise RuntimeError('Invalid dataSourceUnique request')
        yield from util.dataSourceUniquesStreamPandas(self.df, request)

    def sampleDataSourceMeta(self, request: api.DataSourceMetaRequest, context) -> api.DataSourceMetaReply:
        if request.dataSourceId != ds_id:
            context.set_code(grpc.StatusCode.INVALID_ARGUMENT)
            context.set_details(f'Datasource id does not equal requested id: {request.dataSourceId}')
            raise RuntimeError('Invalid sampleDataSourceMeta request')

        reply = util.getDatasourceMetaReplyPandas(self.df, ds_id, ds_name)
        context.set_code(grpc.StatusCode.OK)
        return reply



#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

requirements = ['Click>=7.0', 'pandas', 'numpy', 'PyJWT', 'requests', 'ndjson', 'grpcio>=1.27.2', 'protobuf']

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest>=3', ]

setup(
    author="Datavore Labs",
    author_email='info@datavorelabs.com',
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    description="Python client for datavore. Connection auth and grpc support",
    entry_points={
        'console_scripts': [
            'dv_pyclient=dv_pyclient.cli:main',
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description="dv_pyclient package for client and grpc services",
    include_package_data=True,
    keywords='dv_pyclient',
    name='dv_pyclient',
    packages=find_packages(include=['dv_pyclient', 'dv_pyclient.*']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/datavore-labs/dv-pyclient',
    version='0.3.3',
    zip_safe=False,
)



#!/usr/bin/env python

'''Tests for `dv_pyclient` package.'''

import pytest
import copy
import numpy as np
import pandas as pd

from click.testing import CliRunner

from dv_pyclient import dv_pyclient
from dv_pyclient import cli


@pytest.fixture
def session():
    '''Sample pytest fixture.

    See more at: http://doc.pytest.org/en/latest/fixture.html
    '''
    password = 'dummy password'
    env_conf = {
        'authDomain': 'https://dev.datavorelabs.com/auth',
        'apiDomain': 'https://dev.datavorelabs.com/server',
        'execDomain': 'https://dev.datavorelabs.com/exec'
    }
    return dv_pyclient.login('JP Kosmyna', env_conf, password)


@pytest.fixture
def dataFrame():
    return pd.DataFrame({'A': 1.,
                         'B': pd.Timestamp('20130102'),
                         'C': pd.Series(1, index=list(range(4)), dtype='float32'),
                         'D': np.array([3] * 4, dtype='int32'),
                         'E': pd.Categorical(['test', 'train', 'test', 'train']),
                         'F': pd.Categorical(['a', 'a', 'b', 'a'])})


def test___generateDataSourceLoaderConfig(dataFrame):
    result = dv_pyclient.__generateDataSourceLoaderConfig(
        dataFrame, 'userName', 'dataSourceid', None, [], [])
    print(result)
    assert True


def test___getPreSignedUrl(session):
    dataSourceId = '72c221ff-703e-11ea-9c7f-1fc811f9ee94'
    presignedUrl = dv_pyclient.__getPreSignedUrl(
        session, dataSourceId)
    assert presignedUrl.startswith(
        'http://dev-upload.datavorelabs.com:9000/dv-dev/dv-data-loader/uploads/'+dataSourceId)


def test__setDataSourceLoaderConfig(session):
    dataSourceId = '72c221ff-703e-11ea-9c7f-1fc811f9ee94'
    emptyLoaderConfig = {
        'type': 'CsvDataLoaderConfig',
        'dataSource': {
            'docType': 'DataSource',
            'id': dataSourceId,
        },
        'strategy': 'Overwrite',
        'loaderConfig': {
            'generated': True
        },
        'inputs': {}
    }
    resp = dv_pyclient.__setDatasourceLoaderConfig(
        session, dataSourceId, emptyLoaderConfig)
    assert resp.status_code == 200

def test__getDatasourceLoaderConfig(session):
    dataSourceId = '8eafff0a-7835-11ea-b299-55625c1ef477'
    configJson = dv_pyclient.__getDatasourceLoaderConfig(session, dataSourceId)
    # print(configJson)
    assert configJson != None


def test__validateLoaderConfig_empty():
    # No config
    with pytest.raises(Exception) as e_info:
        dv_pyclient.__validateLoaderConfig({})
    assert 'Empty loader config' in str(e_info)


def test__validateLoaderConfig_noTime():
    # No time columns
    with pytest.raises(Exception) as e_info:
        df = pd.DataFrame({})
        dv_pyclient.__validateLoaderConfig(
            dv_pyclient.__generateDataSourceLoaderConfig(
                df, '', '', None, [], [])
        )
    assert 'Loader config requires non-empty time columns.' in str(e_info)


def test__validateLoaderConfig_noTuples():
    # No time/value tuples
    with pytest.raises(Exception) as e_info:
        df = pd.DataFrame({
            'String': pd.Categorical(['a', 'a', 'b', 'a']),
            'Date': pd.Timestamp('20130102')
        })
        dv_pyclient.__validateLoaderConfig(
            dv_pyclient.__generateDataSourceLoaderConfig(
                df, '', '', None, [], [])
        )
    assert 'Time tuples empty. No column loaded.' in str(e_info)


def test__validateLoaderConfig_configTypeCheck():
    df = pd.DataFrame({
        'String': pd.Categorical(['a', 'a', 'b', 'a']),
        'Date': pd.Timestamp('20130102'),
        'Value': np.array([3] * 4, dtype='int32')
    })
    baseConfig = dv_pyclient.__generateDataSourceLoaderConfig(df, '', '', None, [], [])

    # all keyColumns defined
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['keyColumns'] = ['NotAField']
        dv_pyclient.__validateLoaderConfig(local)
    assert 'key column NotAField not found' in str(e_info)

    # all keyColumns are strings
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['keyColumns'] = ['Date']
        dv_pyclient.__validateLoaderConfig(local)
    assert 'key column Date must be a string' in str(e_info)

    # all valueLabelColumn are defined
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['valueLabelColumn'] = ['NotAField']
        dv_pyclient.__validateLoaderConfig(local)
    assert 'value label NotAField not found' in str(e_info)

    # all valueLabelColumn are strings
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['valueLabelColumn'] = ['Date']
        dv_pyclient.__validateLoaderConfig(local)
    assert 'value label Date must be a string' in str(e_info)

    # all timeColumns are defined
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['timeColumns'] = ['NotAField']
        dv_pyclient.__validateLoaderConfig(local)
    assert 'time column NotAField not found' in str(e_info)

    # all timeColumns are time
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['timeColumns'] = ['String']
        dv_pyclient.__validateLoaderConfig(local)
    assert 'time column String must be a time' in str(e_info)

    # all timeTuples times are defined
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['timeTuples'][0]['timeColumn'] = 'NotAField'
        dv_pyclient.__validateLoaderConfig(local)
    assert 'not found' in str(e_info)

    # all timeTuples times are time
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['timeTuples'][0]['timeColumn'] = 'String'
        dv_pyclient.__validateLoaderConfig(local)
    assert 'must be a time' in str(e_info)

    # all timeTuples values are defined
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['timeTuples'][0]['valueColumn'] = 'NotAField'
        dv_pyclient.__validateLoaderConfig(local)
    assert 'not found' in str(e_info)

    # all timeTuples values are Number
    with pytest.raises(Exception) as e_info:
        local = copy.deepcopy(baseConfig)
        local['loaderConfig']['mapping']['timeTuples'][0]['valueColumn'] = 'String'
        dv_pyclient.__validateLoaderConfig(local)
    assert 'must be a number' in str(e_info)


def test__validateLoaderConfig_dataFrameTypeCheck():
    df = pd.DataFrame({
        'String': pd.Categorical(['a', 'a', 'b', 'a']),
        'Date': pd.Timestamp('20130102'),
        'Value': np.array([3] * 4, dtype='int32')
    })
    config = dv_pyclient.__generateDataSourceLoaderConfig(df, '', '', None, [], [])

    # Each referenced col must exist in the data frame
    with pytest.raises(Exception) as e_info:
        noDateFrame = pd.DataFrame({
            'String': pd.Categorical(['a', 'a', 'b', 'a']),
            'Value': np.array([3] * 4, dtype='int32')
        })
        dv_pyclient.__validateLoaderConfig(config, noDateFrame)
    assert 'data frame missing required field: Date' in str(e_info)

    # Each referenced col must be the correct type
    with pytest.raises(Exception) as e_info:
        wrongTypeFrame = pd.DataFrame({
            'String': pd.Timestamp('20130102'),
            'Date': pd.Timestamp('20130102'),
            'Value': np.array([3] * 4, dtype='int32')
        })
        dv_pyclient.__validateLoaderConfig(config, wrongTypeFrame)
    assert 'ata frame field String must be of type StringColumnConfig.' in str(e_info)


def test__validateLoaderConfig_valid():
    # Completely valid config
    df = pd.DataFrame({
        'Date': pd.Timestamp('20130102'),
        'Value': np.array([3] * 4, dtype='int32')
    })
    assert dv_pyclient.__validateLoaderConfig(
        dv_pyclient.__generateDataSourceLoaderConfig(df, '', '', None, [], []),
        df
    )


def test_publish(session, dataFrame):
    dataSourceId = '72c221ff-703e-11ea-9c7f-1fc811f9ee94'
    resp = dv_pyclient.publish(session, dataSourceId, dataFrame)
    assert resp.status_code == 200


def test_command_line_interface():
    '''Test the CLI.'''
    runner = CliRunner()
    result = runner.invoke(cli.main)
    assert result.exit_code == 0
    assert 'dv_pyclient.cli.main' in result.output
    help_result = runner.invoke(cli.main, ['--help'])
    assert help_result.exit_code == 0
    assert '--help  Show this message and exit.' in help_result.output

def test___getDataFrameSample():
    sampleFrame = pd.DataFrame({
        'CatA': pd.Categorical(['A', 'A', 'B', 'B', 'C']),
        'CatB': pd.Categorical(['X', 'Y', 'X', 'Y', 'Z']),
        'Date': pd.Timestamp('20130102'),
        'Value': np.array(5, dtype='int32')
    })
    sample = dv_pyclient.__getDataFrameSample(sampleFrame)

    # Sampled every row
    assert len(sample['sampleData']) == 5

    # Per-column samples
    assert sample['columnSamples']['CatA'] == list(sampleFrame['CatA'])
    assert sample['columnSamples']['CatB'] == list(sampleFrame['CatB'])
    assert sample['columnSamples']['Date'] == list(map(str, sampleFrame['Date']))
    assert sample['columnSamples']['Value'] == list(map(str, sampleFrame['Value']))



from dv_pyclient.grpc.datavore import dataSources_pb2 as api
from pandas.core.dtypes.common import (
    is_string_dtype,
    is_numeric_dtype,
    is_datetime64_any_dtype,
)
import pandas as pd
import google.protobuf.wrappers_pb2 as proto
import numpy as np


def __isTimeDataType(dataType):
    return dataType in frozenset(['TimeColumnConfig', 'StaticTimeConfig'])


def __isStringDataType(dataType):
    return dataType in frozenset(['StringColumnConfig', 'StaticStringConfig'])


def __isNumberDataType(dataType):
    return dataType in frozenset(['NumberColumnConfig', 'StaticNumberConfig'])


def __isStaticDataType(dataType):
    return dataType in frozenset(['StaticTimeConfig', 'StaticStringConfig', 'StaticNumberConfig'])


def __getDataLoadMappings(columnConfigs, valueModifiers):
    stringColumnsAndMeta = list(filter(lambda c: __isStringDataType(c[1]['dataType']), columnConfigs))
    keyColumnsAndMeta = list(filter(lambda s: not (s in valueModifiers), stringColumnsAndMeta))
    timeColumnsAndMeta = list(filter(lambda c: __isTimeDataType(c[1]['dataType']), columnConfigs))
    valueColumnsAndMeta = list(filter(lambda c: __isNumberDataType(c[1]['dataType']), columnConfigs))

    keyColumns = list(map(lambda c: c[1]['name'], keyColumnsAndMeta))
    timeColumns = list(map(lambda c: c[1]['name'], timeColumnsAndMeta))

    timeTuples = []
    for v in valueColumnsAndMeta:
        for t in timeColumnsAndMeta:
            timeTuples.append(
                api.TimeTupleConfig(timeColumn=t[1]['name'], valueColumn=v[1]['name'])
            )
    return api.DataLoadMapping(
        keyColumns=keyColumns,
        valueModifiers=valueModifiers,
        timeColumns=timeColumns,
        frequency=proto.StringValue(value=None),
        valueLabelColumn=[],
        timeTuples=timeTuples
    )


#######################################
### Pandas helpers to read meta
############
def __getColumnTypeOptions(dType, name):
    if is_numeric_dtype(dType):
        return {'dataType': 'NumberColumnConfig', 'name': name}
    elif is_string_dtype(dType):
        return {'dataType': 'StringColumnConfig', 'name': name}
    if is_datetime64_any_dtype(dType):
        return {'dateFormat': 'ISO_DATE', 'dataType': 'TimeColumnConfig', 'name': name}
    raise Exception(f'Unsupprted dType: {dType}')


def __getSampleRowsPandas(df):
    rowSamples = []
    for idx, row in df[0:100].iterrows():
        rowGrpc = list(map(lambda d: api.OptionalString(value=proto.StringValue(value=str(d))), row.to_list()))
        rowSamples.append(api.RowSample(values=rowGrpc))
    return rowSamples


def __getColumnSamplesPandas(df):
    columnSamples = []
    for col in df.columns:
        colvalues = list(map(lambda d: "" if d is None else str(d), df[col][0:100].tolist()))
        colGrpc = api.ColumnSample(
            columnName=col,
            values=colvalues
        )
        columnSamples.append(colGrpc)
    return columnSamples


def __getColumnConfigsPandas(df: pd.DataFrame):
    typedColumnConfigs = []
    pythonConfigs = []
    for name, dType in df.dtypes.items():
        # Compute the base type
        baseConfig = __getColumnTypeOptions(dType, name)
        pythonConfigs.append(baseConfig)

        # And make the correct grpc model
        if baseConfig['dataType'] == 'StringColumnConfig':
            typed_conf = api.ColumnConfig(stringColumnConfig=api.StringColumnConfig(
                name=name,
                displayLabel=name,
                modifier=api.PredicateModifier.Value('None'),
                ontology=proto.StringValue(value=None)
            ))
            typedColumnConfigs.append(typed_conf)
        elif baseConfig['dataType'] == 'NumberColumnConfig':
            typed_conf = api.ColumnConfig(numberColumnConfig=api.NumberColumnConfig(
                name=name,
                displayLabel=name,
            ))
            typedColumnConfigs.append(typed_conf)
        elif baseConfig['dataType'] == 'TimeColumnConfig':
            typed_conf = api.ColumnConfig(timeColumnConfig=api.TimeColumnConfig(
                name=name,
                displayLabel=name,
                dateFormat=baseConfig['dateFormat']
            ))
            typedColumnConfigs.append(typed_conf)

    return list(zip(typedColumnConfigs, pythonConfigs))


def getDatasourceMetaReplyPandas(df, ds_id, ds_name):
    typedColumnConfigsAndMeta = __getColumnConfigsPandas(df)
    valueModifiers = []
    data_load_mappings = __getDataLoadMappings(typedColumnConfigsAndMeta, valueModifiers)
    rowSamples = __getSampleRowsPandas(df)
    columnSamples = __getColumnSamplesPandas(df)
    return api.DataSourceMetaReply(
        dataSourceId=ds_id,
        dataSourceName=ds_name,
        columnConfigs=list(map(lambda x: x[0], typedColumnConfigsAndMeta)),
        dataLoadMapping=data_load_mappings,
        sampleData=rowSamples,  # repeated RowSample
        columnSamples=columnSamples,  # repeated ColumnSample
    )


def dataSourceUniquesStreamPandas(df, request):
    chunk_size = 100  # Determines the number of records per rpc batch
    columns = list(request.columns)
    unique_df = df[columns].drop_duplicates()
    for chunk_df in np.array_split(unique_df, chunk_size):
        data_records = []
        for idx, row in chunk_df.iterrows():
            strings, numbers, times = [], [], []
            for c in columns:
                col_value = row[c] if row[c] is not None else ""
                strings.append(api.OptionalString(value=proto.StringValue(value=col_value)))
            data_records.append(api.DataRecord(strings=strings, numbers=numbers, times=times))
        yield api.DataRecordsReply(records=data_records)


def dataSourceQueryStreamPandas(df, request):
    # Make and resolve the data for each line requested.
    # We yield batches of DataRecordsReply, one for each line requested
    for querystr in request.lineQueries:
        columns = []
        column_types = []
        filterExprs = []
        # Make the filter expression from columns
        for filt in querystr.columns:
            columns.append(filt.name)
            column_types.append(filt.type)
            if filt.type == api.ColumnType.Value("String") and len(filt.stringFilter) > 0:
                filt_str = ' or '.join(f'{filt.name} == "{filtValue.value.value}"' for filtValue in filt.stringFilter)
                filterExprs.append(f'({filt_str})')
            elif filt.type == api.ColumnType.Value("Number") and len(filt.numberFilter) > 0:
                if len(filt.numberFilter) == 1:
                    filt_num = f'{filt.name} == {filt.numberFilter[0].value.value}'
                    filterExprs.append(f'({filt_num})')
                else:
                    filt_num = f'{filt.name} >= {filt.numberFilter[0].value.value} and {filt.name} < {filt.numberFilter[1].value.value}'
                    filterExprs.append(f'({filt_num})')
            #TODO: Support time filter after server format is known
            elif type == "Time":
                if len(filt.timeFilter) == 1:
                    f'{filt.name} == {filt.timeFilter[0].value.value}'
                else:
                    f'{filt.name} >= {filt.timeFilter[0].value.value} and {filt.name} < {filt.timeFilter[1].value.value}'
        line_query = ' and '.join(filterExprs)

        # Filter data
        line_result_df = df[columns].query(line_query)
        # Inplace convert all date columns to unixepoch
        date_cols = list(map(lambda x: x[0],
                             filter(lambda t: t[1] == api.ColumnType.Value("Time"), list(zip(columns, column_types)))))
        for date_col in date_cols:
            line_result_df[date_col] = line_result_df[date_col].astype(np.int64)

        # TODO: Sort values by date columns
        line_result_df.sort_values(by=date_col, inplace=True)

        # Serialize
        data_records = []
        for idx, row in line_result_df.iterrows():
            strings, numbers, times = [], [], []
            for c, c_type in zip(columns, column_types):
                if c_type == api.ColumnType.Value("String"):
                    strings.append(api.OptionalString(value=proto.StringValue(value=row[c])))
                elif c_type == api.ColumnType.Value("Number"):
                    numbers.append(api.OptionalNumber(value=proto.DoubleValue(value=row[c])))
                elif c_type == api.ColumnType.Value("Time"):
                    times.append(api.OptionalTime(value=proto.Int64Value(value=row[c])))
            data_records.append(api.DataRecord(strings=strings, numbers=numbers, times=times))
        yield api.DataRecordsReply(records=data_records)



from concurrent import futures
import logging
import grpc

from dv_pyclient.grpc.datavore import dataSources_pb2_grpc as rpc
from dv_pyclient.grpc import test_datasource_server as ds


def serve():
    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))

    rpc.add_RemoteDataSourceServicer_to_server(ds.TestDatasource(), server)
    server.add_insecure_port('[::]:50051')
    server.start()
    server.wait_for_termination()


if __name__ == '__main__':
    logging.basicConfig()
    serve()



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from dv_pyclient.grpc import dataSources_pb2 as dv__pyclient_dot_grpc_dot_dataSources__pb2


class RemoteDataSourceStub(object):
  """The RemoteDataSource service definition.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ListDataSources = channel.unary_unary(
        '/com.datavorelabs.common.protos.RemoteDataSource/ListDataSources',
        request_serializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.ListDataSourcesRequest.SerializeToString,
        response_deserializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.ListDataSourcesReply.FromString,
        )
    self.dataSourceUniques = channel.unary_stream(
        '/com.datavorelabs.common.protos.RemoteDataSource/dataSourceUniques',
        request_serializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataSourceUniquesRequest.SerializeToString,
        response_deserializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataRecordsReply.FromString,
        )
    self.sampleDataSourceMeta = channel.unary_unary(
        '/com.datavorelabs.common.protos.RemoteDataSource/sampleDataSourceMeta',
        request_serializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataSourceMetaRequest.SerializeToString,
        response_deserializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataSourceMetaReply.FromString,
        )
    self.dataSourceQuery = channel.unary_stream(
        '/com.datavorelabs.common.protos.RemoteDataSource/dataSourceQuery',
        request_serializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataSourceQueryRequest.SerializeToString,
        response_deserializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataRecordsReply.FromString,
        )


class RemoteDataSourceServicer(object):
  """The RemoteDataSource service definition.
  """

  def ListDataSources(self, request, context):
    """Return a list of dataSources this remote service has
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def dataSourceUniques(self, request, context):
    """Return unique records for indexing into search
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def sampleDataSourceMeta(self, request, context):
    """Returns the meta needed to read the dataRecords as lines
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def dataSourceQuery(self, request, context):
    """Sends a list of lines to retrieve, and gets the dataRecords back
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RemoteDataSourceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ListDataSources': grpc.unary_unary_rpc_method_handler(
          servicer.ListDataSources,
          request_deserializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.ListDataSourcesRequest.FromString,
          response_serializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.ListDataSourcesReply.SerializeToString,
      ),
      'dataSourceUniques': grpc.unary_stream_rpc_method_handler(
          servicer.dataSourceUniques,
          request_deserializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataSourceUniquesRequest.FromString,
          response_serializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataRecordsReply.SerializeToString,
      ),
      'sampleDataSourceMeta': grpc.unary_unary_rpc_method_handler(
          servicer.sampleDataSourceMeta,
          request_deserializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataSourceMetaRequest.FromString,
          response_serializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataSourceMetaReply.SerializeToString,
      ),
      'dataSourceQuery': grpc.unary_stream_rpc_method_handler(
          servicer.dataSourceQuery,
          request_deserializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataSourceQueryRequest.FromString,
          response_serializer=dv__pyclient_dot_grpc_dot_dataSources__pb2.DataRecordsReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'com.datavorelabs.common.protos.RemoteDataSource', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
